<?php

/* Category.php *
 * This script allows to manage the categories
 * Categories can be managed by only admins or the root
 */


/*
 * Starting Session
 * If the user has not rights of managing categories
 * Go to login.php
 */

session_start();
if (!($_SESSION["class"] == "admin" || $_SESSION["class"] == "root"))
{
    header("Location: login.php"); exit();
}


/*
 * Importing db.php
 * Creating a new DataBase object
 */

require("./db.php");
$DB = new DataBase();

require("../langs/".$DB->get_setting("lang").".php");
$lng = $_lang["category.php"];
$lng["returntomanager"] = $_lang["returntomanager"];


/*
 * Getting "do" variable
 * That tells the script what will it do 
 */

$do = $_REQUEST["do"];




/*
 * If "do" equals "new"
 * It means a new category will be created
 */

if ($do=="new")
{
    /*
     * Getting "ok" variable
     * If "ok" has been defined
     * It means the user has filled the "new category form"
     * 
     * A DataBase Operation will be done
     */
    
    $ok = $_POST["ok"];
    if ($ok)
    {
        $name = $_POST["name"];
        
        /*
         * If there is a category with same name
         * Return to the form
         */
        
        if ($DB->is_same($name)) { header("Location: category.php?do=new&err=1"); exit();}
        
        
        
        
        /*
         * If the user has not filled the "name"
         * Return to the form
         */
        
        elseif ($name == "") { header("Location: category.php?do=new&err=2"); exit();}
        
        
        
        
        /*
         * Else, insert the data into the DataBase
         * And make site
         */
        
        else
        {        
            $description = $_POST["description"];
            $DB->new_category($name, $description);
			$_SESSION["from"] = "category.php";
            header("Location: make_site.php");
            exit();
        }
    }
    
    
    
    
    /*
     * If "ok" variable has not been defined
     * It means the user has not filled the form yet
     * The script will show the panel contains the form
     */
    
    else
    {
        /*
         * Catch the errors if there is some
         */
        
        if ($_GET["err"] == "1")
            { $error_message = $lng["exist"]; }
        
        elseif ($_GET["err"] == "2")
            { $error_message = $lng["enter_name"]; }
        
        
        /*
         * Defining panel variables
         */
        
        $side1 =  $error_message.'<br/>
        <form action="category.php" id="newcategory" method="post">
        <dl>
        <dt><label for="name">'.$lng["category"].'</label></dt>
        <dd><input name="name" type="text" id="name" /></dd>
        
        <dt><label for="description">'.$lng["description"].'</label></dt>
        <dd><input name="description" type="text" id="description" /></dd>

        <input type="hidden" id="do" name="do" value="new" />
        <input type="hidden" id="ok" name="ok" value="1" />
        
        <dt><input type="submit" value="'.$lng["submit"].'" /></dt>
        </dl>
        </form>';
        
        $side2 = '<a href="index.php">'.$lng["returntomanager"].'</a><br/>'.
		'<a href="category.php">'.$lng["gotocategories"].'</a>';
        
        $page_title = $lng["newcategory"];
        
        
        
        
        
        /*
         * Importing panel.php
         * Creating a new panel object
         * Showing the panel
         */
        
        require('./panel.php');        
        $panel = new Panel();
        $panel->show($page_title, $side1, $side2);
    }
}




/*
 * If $do equals "edit"
 * It means a category will be edited
 */

elseif ($do=="edit")
{
    /*
     * Getting id of the category that will be edited
     * From id getting category data
     */
    
    $what = $_REQUEST["what"];
    $what = $DB->get_category($what);
    
    
    
    
    /*
     * Getting "ok" variable
     * If "ok" has been defined
     * It means the user has been edited the category
     * A Database Operation will be done
     */
    
    if ($_POST["ok"])
    {
        $name = $_POST["name"];
        
        /*
         * If there is a category with same name
         * Return to the form
         */
        
        if ($DB->is_same($name) && $what["name"] != $name) { header("Location: category.php?do=edit&what=".$what."&err=1"); exit();}
        
        elseif ($name == "") { header("Location: category.php?do=edit&what=".$what."&err=2"); exit();}
        
        
        /*
         * Else, update category data
         * Make the site
         */
        
        else
        {        
            $description = $_POST["description"];
            $DB->edit_category($what["id"], $name, $description);
			$_SESSION["from"] = "category.php";
            header("Location: make_site.php");
            exit();        
        }
    }
    
    
    
    
    /*
     * If "do" variable has not been defined
     * It means the user has not filled the form yet
     * The script will show the form
     */
    
    else
    {
        /*
         * Catch the errors if there are some
         */
        
        if ($_GET["err"] == "1")
            { $error_message = $lng["exist"]; }
            
        elseif ($_GET["err"] == "2")
            { $error_message = $lng["enter_name"]; }
        
        
        
        
        /*
         * Defining Panel variables $side1, $side2, $page_title
         */
        
        $side1 =  $error_message.'<br/>
        <form action="category.php" id="categoryedit" method="post">
        <dl>
        <dt><label for="name">'.$lng["category"].'</label></dt>
        <dd><input name="name" type="text" id="name" value="'.$what["name"].'"/></dd>
        
        <dt><label for="description">'.$lng["description"].'</label></dt>
        <dd><input name="description" type="text" id="description" value="'.$what["description"].'"/></dd>

        <input type="hidden" id="do" name="do" value="edit" />
        <input type="hidden" id="ok" name="ok" value="1" />
        <input type="hidden" id="what" name="what" value="'.$what["id"].'" />
        <dt><input type="submit" value="'.$lng["submit"].'" /></dt>
        </dl>
        </form>';
        
        $side2 = '<a href="index.php">'.$lng["returntomanager"].'</a><br/>'.
		'<a href="category.php">'.$lng["gotocategories"].'</a>';
        
        $page_title = $lng["editcategory"];
        
        
        
        
        /*
         * Importing panel.php file
         * Creating a new panel object
         * Showing the object
         */
        
        require('./panel.php');        
        $panel = new Panel();
        $panel->show($page_title, $side1, $side2);
    }
}




/*
 * If "do" equals "delete"
 * It means a category will be deleted
 */

elseif ($do=="delete")
{
    /*
     * Getting id of the category
     * Deleting category
     * Deleting all relations of the category
     * Making the site
     */
    
    $what = $_GET["what"];
    $DB->delete_category($what);
    $DB->delete_relations("category", $what);
	$_SESSION["from"] = "category.php";
    header("Location: make_site.php");
    exit();       
}




/*
 * If "do" variable has not defined
 * It means the script will show the category manager
 * It will show the list of categories
 */

else
{
    /*
     * Defining panel variables $side1, $side2, $page_title
     */
      
    $page_title = $lng["categories"];
    $side1 = '';
    
    
    
    
    /*
     * If there is not any categories
     * Say "There is not any categories"
     * Else list them
     */
    
    $ALL = $DB->get_categories();
    if (count($ALL)>0) {
        $side1 = '<table id="category_table">'.
		'<tr><td><b><u>'.$lng["category"].'</u></b></td><td><b><u>'.$lng["description"].'</u></b></td></tr>';
        foreach($ALL as $category)
        {
            $side1 .= '<tr>';
            $side1 .= '<td>'.$category["name"].'</td><td style="font-size: 10px;">'.$category["description"].'</td>';
            $side1 .= '<td>'. '<a href="category.php?do=edit&what='.$category["id"].'">'.$lng["edit"].'</a></td>';
            $side1 .= '<td>'. '&nbsp;&nbsp;&nbsp;<a href="category.php?do=delete&what='.$category["id"].'">'.$lng["delete"].'</a></td></tr>';
        } $side1 .= '</table>';}
        
    else { $side1 .= $lng["nocategory"]; }    
    
    $side2 = 
	'<a href="index.php">'.$lng["returntomanager"].'</a><br/>'.
	'<a href="category.php?do=new">'.$lng["addcategory"].'</a>';
    
    
    
    
    /*
     * Import panel.php file
     * Create a new panel object
     * Show it
     */
    require('./panel.php');        
    $panel = new Panel();
    $panel->show($page_title, $side1, $side2);
}

?> 
